#
# spec file for package python-wsgi_intercept
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-wsgi_intercept
Version:        1.13.1
Release:        1.2
Summary:        Library for installing a WSGI application in place of a real URI for testing
License:        MIT
URL:            https://github.com/cdent/python3-wsgi-intercept
Source:         https://files.pythonhosted.org/packages/source/w/wsgi_intercept/wsgi_intercept-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module httplib2}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest >= 2.4}
BuildRequires:  %{python_module requests >= 2.0.1}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module urllib3 >= 1.11.0 with %python-urllib3 < 2}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-six
Recommends:     python-requests >= 2.0.1
BuildArch:      noarch
%python_subpackages

%description
Testing a WSGI application normally involves starting a server at a local host
and port, then pointing your test code to that address. Instead, this library
lets you intercept calls to any specific host/port combination and redirect
them into a `WSGI application`_ importable by your test program.  Thus, you
can avoid spawning multiple processes or threads to test your Web app.

%prep
%setup -q -n wsgi_intercept-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand rm -r %{buildroot}%{$python_sitelib}/wsgi_intercept/tests
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export WSGI_INTERCEPT_SKIP_NETWORK=true
%pytest

%files %{python_files}
%doc README
%license LICENSE
%{python_sitelib}/wsgi_intercept
%{python_sitelib}/wsgi_intercept-%{version}.dist-info

%changelog
* Fri Aug 16 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.13.1:
  * Update argument processing for modern requests
* Sat Jan  6 2024 Dirk Müller <dmueller@suse.com>
- update to 1.13.0:
  * Support Python 3.12
* Tue Jul 25 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.12.1:
  * Pin urllib3 to < 2.0.0 (#70)
- Switch to pyproject macros
* Wed Nov  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.11.0
  * refer to pytest not py.test in tests (#69)
- Update to version 1.10.0
  * Correct handling of a environ keys in python2 (#66)
  * Accept urllib3 server_hostname keyword
  * Test by git hub actions (#64)
  * Merge pull request #63 from santosh653/master
  * Update .travis.yml
* Tue Oct 11 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.10.0
  * No upstream changelog
* Sat Mar 14 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Thu Feb  6 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.9.2
  * Don't send headers until we've read some results
  * Update testing to include python 3.7 and 3.8
  * Adding skipnetwork decorator to external resource
  * Enable support for verify=False set in requests library.
* Wed Nov  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.9.0:
  * Fix with new httplib2 included upstream
- Remove patch httplib2.patch
* Tue Oct 15 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to build with latest httplib2 releases:
  * httplib2.patch
* Tue May 28 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in descriptions.
* Fri May 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.8.1:
  * Fixes issues with latest urllib
* Thu Mar 21 2019 Thomas Bechtold <tbechtold@suse.com>
- Add back devel dependency to be able to build on SLE12SP4. Without
  it, the build fails with:
  ImportError: cannot import name HTTPSConnection
* Sat Mar  9 2019 John Vandenberg <jayvdb@gmail.com>
- Fix removal of tests from runtime package
- Run tests on both Python 2 and 3
- Use documented method of disabling network unit tests
- Remove no longer needed wsgi_intercept-disable-testbogusdomain.patch
- Add fdupes
- Update to v1.8.0
  * Add wheel support
- from v1.7.0
  * Allow nested interceptor context managers
- from v1.6.0
  * set wsgi.errors to sys.stderr
- from v1.5.1
  * Use fewer dependencies when building docs
  * Ignore `socket_options` for urllib3
* Thu Jan 10 2019 Jonathan Brownell <jbrownell@suse.com>
- Support older OS targets by adding a fallback for Recommends:
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Jul  5 2017 tbechtold@suse.com
- convert to singlespec
* Tue May 16 2017 dmueller@suse.com
- update to 1.5.0:
  * compatibility fixes
* Wed Sep 28 2016 tbechtold@suse.com
- Add missing BuildRequires for pyrthon-six
* Tue Sep 27 2016 dmueller@suse.com
- update to 1.4.1
  * Correct the bytes v str problem
  * Fix pep8 errors in doc string
  * Move tests from the test dir into wsgi_intercept/tests
* Fri Sep  2 2016 tbechtold@suse.com
  update to version v1.3.1
  * Dedupe the urllib3 monkey patching code
  * Fix for python3 in use of urllib3.Response.data
  * add urllib3 to testing requires
  * update readme
  * Skip the network tests if WSGI_INTERCEPT_SKIP_NETWORK
  * Release 1.2.1
  * Force urllib3 to raise errors immediately
  * Release 1.3.0
  * Release 1.3.1
  * Small fix in docstring
  * Add urllib3 to the docs
  * make urllib3 min requirement explicit
  * Add support for intercepting urllib3
  * Don't use six when testing httplib
  * Release 1.2.0
  * Ensure header values are native str
  * fix typo in test/README
  * Release 1.1.3
- Use pypi.io (https) as Source url
* Mon Feb  1 2016 dmueller@suse.com
- update to 1.1.2:
  * no changelog available
* Mon Feb  1 2016 dmueller@suse.com
- update to 0.10.3:
  * bugfixes, no changelog available
* Thu May 14 2015 benoit.monin@gmx.fr
- update to version 0.10.0:
  * no changelog available
- refresh wsgi_intercept-disable-testbogusdomain.patch
- update project URL
- skip tests trying to access google.com with command line option
* Wed Feb  5 2014 speilicke@suse.com
- Use py.test rather than nosetests, testsuite uses py.test specific features
* Thu Jan 30 2014 speilicke@suse.com
- Added wsgi_intercept-disable-testbogusdomain.patch: Disable some tests
  on 12.3 where patching fails
* Thu Jan 30 2014 speilicke@suse.com
- Update to version 0.6.1:
  + Better testing dependency structure
- Dropped patches:
  + 0001-Depend-on-requests-2.0.1.patch (merged upstream)
* Thu Jan 30 2014 speilicke@suse.com
- Added 0001-Depend-on-requests-2.0.1.patch: Require requests>=2.0.1.
  Really a requirement
* Fri Jan 17 2014 speilicke@suse.com
- Don't install testsuite globally
- Run testsuite
- Fix requirement list
- Recommend python-requests for the requests-based backend
  (don't recommend httplib2, it isn't any better than the stdlib
  module 'httplib' due to it's SSL insufficencies)
* Fri Jan 17 2014 dmueller@suse.com
- remove excessive buildrequires that are not used due to
  tests being commented out
* Fri Nov 15 2013 p.drouand@gmail.com
- Update to version 0.6.0
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri Mar 15 2013 speilicke@suse.com
- Initial version
